==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/AuditBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AuditBuilder extends io.fabric8.openshift.api.model.AuditFluentImpl<io.fabric8.openshift.api.model.AuditBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.Audit,io.fabric8.openshift.api.model.AuditBuilder>{
  public AuditBuilder() {
    this(false);
  }
  public AuditBuilder(java.lang.Boolean validationEnabled) {
    this(new Audit(), validationEnabled);
  }
  public AuditBuilder(io.fabric8.openshift.api.model.AuditFluent<?> fluent) {
    this(fluent, false);
  }
  public AuditBuilder(io.fabric8.openshift.api.model.AuditFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Audit(), validationEnabled);
  }
  public AuditBuilder(io.fabric8.openshift.api.model.AuditFluent<?> fluent,io.fabric8.openshift.api.model.Audit instance) {
    this(fluent, instance, false);
  }
  public AuditBuilder(io.fabric8.openshift.api.model.AuditFluent<?> fluent,io.fabric8.openshift.api.model.Audit instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProfile(instance.getProfile()); 
    this.validationEnabled = validationEnabled; 
  }
  public AuditBuilder(io.fabric8.openshift.api.model.Audit instance) {
    this(instance,false);
  }
  public AuditBuilder(io.fabric8.openshift.api.model.Audit instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withProfile(instance.getProfile()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.AuditFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.Audit build() {
    Audit buildable = new Audit(fluent.getProfile());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AuditBuilder that = (AuditBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.2-sources.jar: io/fabric8/openshift/api/model/AuditBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AuditBuilder extends io.fabric8.openshift.api.model.AuditFluentImpl<io.fabric8.openshift.api.model.AuditBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.Audit,io.fabric8.openshift.api.model.AuditBuilder>{
  public AuditBuilder() {
    this(false);
  }
  public AuditBuilder(java.lang.Boolean validationEnabled) {
    this(new Audit(), validationEnabled);
  }
  public AuditBuilder(io.fabric8.openshift.api.model.AuditFluent<?> fluent) {
    this(fluent, false);
  }
  public AuditBuilder(io.fabric8.openshift.api.model.AuditFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Audit(), validationEnabled);
  }
  public AuditBuilder(io.fabric8.openshift.api.model.AuditFluent<?> fluent,io.fabric8.openshift.api.model.Audit instance) {
    this(fluent, instance, false);
  }
  public AuditBuilder(io.fabric8.openshift.api.model.AuditFluent<?> fluent,io.fabric8.openshift.api.model.Audit instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withProfile(instance.getProfile()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public AuditBuilder(io.fabric8.openshift.api.model.Audit instance) {
    this(instance,false);
  }
  public AuditBuilder(io.fabric8.openshift.api.model.Audit instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withProfile(instance.getProfile()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.AuditFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.Audit build() {
    Audit buildable = new Audit(fluent.getProfile());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AuditBuilder that = (AuditBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
